@@ -10,8 +10,8 @@ MACRODIR=mk/autoconf
 aclocal -I $MACRODIR
 
 # generate a Jamconfig.in
-autoconf --trace=AC_SUBST | \
-  sed -e 's/configure.ac:[0-9]*:AC_SUBST:\([^:]*\).*/\1 ?= "@\1@" ;/g' \
+autoconf --trace=AC_SUBST \
+  | sed -e 's/configure.ac:[0-9]*:AC_SUBST:\([^:]*\).*/\1 ?= "@\1@" ;/g' \
   > Jamconfig.in
 # seems autoconf --trace misses some things :-/
 echo 'INSTALL ?= "@INSTALL@" ;' >> Jamconfig.in
